@@ -226,7 +226,9 @@ class Country:
                 cls.set_country_name_mappings(country_name_mappings)
             if use_live:
                 try:
-                    countries = hxl.data(cls._ochaurl)
+                    countries = hxl.data(
+                        cls._ochaurl, InputOptions(encoding="utf-8")
+                    )
                 except OSError:
                     logger.exception(
                         "Download from OCHA feed failed! Falling back to stored file."
@@ -237,7 +239,7 @@ class Country:
                         "Countries & Territories Taxonomy MVP - C&T Taxonomy with HXL Tags.csv",
                         Country,
                     ),
-                    InputOptions(allow_local=True),
+                    InputOptions(allow_local=True, encoding="utf-8"),
                 )
             cls.set_countriesdata(countries)
         return cls._countriesdata
@@ -779,6 +781,12 @@ class Country:
         if iso3 is not None:
             return iso3, True
 
+        # regex lookup
+        for iso3, regex in countriesdata["aliases"].items():
+            index = re.search(regex, country.upper())
+            if index is not None:
+                return iso3, False
+
         if len(country) < min_chars:
             return None, False
 
@@ -790,12 +798,6 @@ class Country:
                         return 35
                     return 17
 
-        # regex lookup
-        for iso3, regex in countriesdata["aliases"].items():
-            index = re.search(regex, country.upper())
-            if index is not None:
-                return iso3, False
-
         # fuzzy matching
         expanded_country_candidates = cls.expand_countryname_abbrevs(country)
         match_strength = 0
